@@ -5,21 +5,12 @@ import re
 from .log_support import logger
 from functools import lru_cache
 from typing import Sequence, Collection
+from executor.sql_support import require_limit
 from executor import get, query, select, DBError, Engine
 from .constant import CACHE_SIZE, LIMIT_1, DEFAULT_KEY_FIELD, MYSQL_COLUMN_SQL, MYSQL_SELECT_KEY, POSTGRES_COLUMN_SQL,\
     SQLITE_SELECT_KEY
 
 
-def require_limit(sql: str):
-    lower_sql = sql.lower()
-    if 'limit' not in lower_sql:
-        return True
-    idx = lower_sql.rindex('limit')
-    if idx > 0 and ')' in lower_sql[idx:]:
-        return True
-    return False
-
-
 def get_page_start(page_num: int, page_size: int):
     assert page_num >= 1 and page_size >= 1, "'page_name' and 'page_size' should be higher or equal to 1"
     return (page_num - 1) * page_size
@@ -116,8 +107,8 @@ class PostgresDialect(BaseDialect):
     @staticmethod
     @lru_cache(maxsize=CACHE_SIZE)
     def _get_key_seq_from_sql(sql: str):
-        table = re.search('(?<=into )\w+', sql, re.I)
-        key_seq = PostgresDialect.build_key_seq(table.group())
+        table_name = re.search('(?<=into )\w+', sql, re.I)
+        key_seq = PostgresDialect.build_key_seq(table_name.group())
         logger.warning("'key_seq' is None, will use default '{}' from sql.".format(key_seq))
         return key_seq
 
